@@ -1,6 +1,6 @@
-;;; emacspeak-aumix.el --- Setting Audio Mixer
-;;; $Id: emacspeak-aumix.el,v 20.0 2004/05/01 01:16:22 raman Exp $
-;;; $Author: raman $
+;;; emacspeak-aumix.el --- Configure audio device settings
+;;; $Id: emacspeak-aumix.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to conveniently set audio display
 ;;; Keywords: Emacspeak, Audio Desktop
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2004/05/01 01:16:22 $ |
-;;;  $Revision: 20.0 $ |
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4670 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2003, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -57,7 +57,7 @@
 ;;}}}
 ;;{{{ Variables
 
-(defvar emacspeak-aumix-program "aumix"
+(defvar emacspeak-aumix-program "/usr/bin/aumix"
   "Program that sets up the mixer.")
 
 (defvar emacspeak-aumix-channel-table (make-hash-table)
@@ -104,13 +104,6 @@ display."
   :group 'emacspeak-aumix
   :type 'boolean)
 
-(defcustom emacspeak-aumix-midi-available-p nil
-  "*Set to T if   midi is available."
-  :group 'emacspeak-aumix
-  :type 'boolean)
-
-(setq emacspeak-aumix-midi-available-p
-      (file-exists-p "/usr/bin/stdiosynth"))
 ;;}}}
 ;;{{{ emacspeak-aumix
 
@@ -123,6 +116,11 @@ display."
   "*Name of file containing personal aumix settings."
   :group 'emacspeak-aumix
   :type 'string)
+;;;###autoload
+(defcustom emacspeak-alsactl-program "alsactl"
+  "ALSA sound controller used to restore settings."
+  :type 'string
+  :group 'emacspeak-aumix)
 
 ;;;###autoload
 (defcustom emacspeak-aumix-reset-options
@@ -132,16 +130,25 @@ display."
   "*Option to pass to aumix for resetting to default values."
   :group 'emacspeak-aumix
   :type 'string)
+
 ;;;###autoload
 (defun emacspeak-aumix-reset ()
   "Reset to default audio settings."
   (interactive)
   (declare (special emacspeak-aumix-program
+                    emacspeak-alsactl-program
                     emacspeak-aumix-reset-options))
-  (shell-command
-   (format "%s %s"
-           emacspeak-aumix-program
-           emacspeak-aumix-reset-options))
+  (cond
+   ((executable-find emacspeak-alsactl-program)
+    (shell-command
+     (format "%s restore"
+             emacspeak-alsactl-program)))
+   ((and (file-exists-p emacspeak-aumix-program)
+         (file-executable-p emacspeak-aumix-program))
+    (shell-command
+     (format "%s %s"
+             emacspeak-aumix-program
+             emacspeak-aumix-reset-options))))
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)))
 (eval-when-compile (require 'emacspeak-forms))
@@ -207,7 +214,7 @@ you are done."
   (let ((emacspeak-speak-messages nil))
     (shell-command
      (format "%s -w +%s"
-	     emacspeak-aumix-program  gain))
+             emacspeak-aumix-program  gain))
     (emacspeak-auditory-icon 'select-object) ))
 
 ;;;###autoload
@@ -218,7 +225,7 @@ you are done."
   (let ((emacspeak-speak-messages nil))
     (shell-command
      (format "%s -w -%s"
-	     emacspeak-aumix-program  gain))
+             emacspeak-aumix-program  gain))
     (emacspeak-auditory-icon 'select-object)))
 
 ;;;###autoload
@@ -229,7 +236,7 @@ you are done."
   (let ((emacspeak-speak-messages nil))
     (shell-command
      (format "%s -v +%s"
-	     emacspeak-aumix-program  gain))
+             emacspeak-aumix-program  gain))
     (emacspeak-auditory-icon 'select-object)))
 
 ;;;###autoload
@@ -240,7 +247,7 @@ you are done."
   (let ((emacspeak-speak-messages nil))
     (shell-command
      (format "%s -v -%s"
-	     emacspeak-aumix-program  gain))
+             emacspeak-aumix-program  gain))
     (emacspeak-auditory-icon 'select-object)))
 
 ;;}}}
