@@ -1,21 +1,21 @@
 ;;; emacspeak-personality.el ---Emacspeak's new personality interface
-;;; $Id: emacspeak-personality.el,v 20.0 2004/05/01 01:16:23 raman Exp $
-;;; $Author: raman $
-;;; Description:  Contains the functions for speaking various chunks of text
-;;; Keywords: Emacspeak,  Spoken Output
+;;; $Id: emacspeak-personality.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
+;;; Description:  Voice lock implementation
+;;; Keywords: Emacspeak,  Spoken Output, audio formatting
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2004/05/01 01:16:23 $ |
-;;;  $Revision: 20.0 $ |
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4555 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2003, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -68,7 +68,7 @@
 ;;; visual characteristics --this was a key goal of the original
 ;;; Emacspeak design and it will be preserved going forward.
 
-;;; Finally, I may add better support for overlays --again this was a
+;;; Finally, I am adding  better support for overlays --again this was a
 ;;; part of Emacs that was at its nascent stage in 1994, but is now
 ;;; stable.
 
@@ -94,53 +94,55 @@
     (setq-default voice-lock-mode t)))
 
 ;;}}}
-;;{{{ cumulative personalities 
+;;{{{ cumulative personalities
 
 ;;;###autoload
-(defun emacspeak-personality-put (start end personality object)
+(defsubst emacspeak-personality-put (start end personality object)
   "Apply personality to specified region, over-writing any current
 personality settings."
   (when (and (integer-or-marker-p start)
-             (integer-or-marker-p end ))
+             (integer-or-marker-p end )
+             (not (= start end)))
     (let ((v (if (listp personality)
-                 (remove-duplicates personality :test #'eq)
+                 (delete-duplicates personality :test #'eq)
                personality)))
       (ems-modify-buffer-safely
-       (put-text-property start end 'personality v object)))))
+       (ad-Orig-put-text-property start end 'personality v object)))))
 
 ;;;###autoload
 (defun emacspeak-personality-append  (start end personality &optional object )
   "Append specified personality to text bounded by start and end.
 Existing personality properties on the text range are preserved."
   (when (and (integer-or-marker-p start)
-             (integer-or-marker-p end ))
+             (integer-or-marker-p end )
+             (not (= start end)))
     (ems-modify-buffer-safely
      (let ((v (if (listp personality)
-                  (remove-duplicates personality :test #'eq)
+                  (delete-duplicates personality :test #'eq)
                 personality))
            (orig (get-text-property start 'personality object))
-	   (new nil)
-	   (extent
-	    (next-single-property-change
-	     start 'personality object end)))
+           (new nil)
+           (extent
+            (next-single-property-change
+             start 'personality object end)))
        (cond
-	((null orig)			;simple case
-	 (put-text-property start extent 'personality v object)
-	 (when (< extent end)
-	   (emacspeak-personality-append extent end v object)))
-	(t			       ;accumulate the new personality
-	 (unless (or (equal  v orig)
+        ((null orig)                    ;simple case
+         (ad-Orig-put-text-property start extent 'personality v object)
+         (when (< extent end)
+           (emacspeak-personality-append extent end v object)))
+        (t                             ;accumulate the new personality
+         (unless (or (equal  v orig)
                      (listp orig)
-                     (and (listp orig) (memq v orig)))
-	   (setq new
-		 (remove-duplicates
-		  (append
-		   (if (listp orig) orig (list orig))
-		   (if (listp v) v (list v)))))
-	   (put-text-property start extent
-			      'personality new object))
-	 (when (< extent end)
-	   (emacspeak-personality-append extent end v object))))))))
+                     (and (listp orig)(memq v orig)))
+           (setq new
+                 (delete-duplicates
+                  (nconc
+                   (if (listp orig) orig (list orig))
+                   (if (listp v) v (list v)))))
+           (ad-Orig-put-text-property start extent
+                                      'personality new object))
+         (when (< extent end)
+           (emacspeak-personality-append extent end v object))))))))
 
 ;;;###autoload
 (defun emacspeak-personality-prepend  (start end
@@ -148,70 +150,71 @@ Existing personality properties on the text range are preserved."
   "Prepend specified personality to text bounded by start and end.
 Existing personality properties on the text range are preserved."
   (when (and (integer-or-marker-p start)
-             (integer-or-marker-p end ))
+             (integer-or-marker-p end )
+             (not (= start end)))
     (ems-modify-buffer-safely
-     (let ((v (if
-                  (listp personality)
-		  (remove-duplicates personality :test #'eq)
-		personality))
+     (let ((v (if (listp personality)
+                  (delete-duplicates personality :test #'eq)
+                personality))
            (orig (get-text-property start 'personality object))
-	   (new nil)
-	   (extent
-	    (next-single-property-change
-	     start 'personality object end)))
+           (new nil)
+           (extent
+            (next-single-property-change
+             start 'personality object end)))
        (cond
-	((null orig)			;simple case
-	 (put-text-property start extent 'personality v object)
-	 (when (< extent end)
-	   (emacspeak-personality-prepend extent end v object)))
-	(t			       ;accumulate the new personality
-	 (unless (or (equal v orig)
-		     (listp orig)
-		     (and (listp orig) (memq v orig)))
-	   (setq new
-		 (remove-duplicates
-		  (append
-		   (if (listp v) v (list v))
-		   (if (listp orig) orig (list orig)))))
-	   (put-text-property start extent
-			      'personality new object))
-	 (when (< extent end)
-	   (emacspeak-personality-prepend extent end v object))))))))
+        ((null orig)                    ;simple case
+         (ad-Orig-put-text-property start extent 'personality v object)
+         (when (< extent end)
+           (emacspeak-personality-prepend extent end v object)))
+        (t                             ;accumulate the new personality
+         (unless (or (equal v orig)
+                     (listp orig)
+                     (and (listp orig) (memq v orig)))
+           (setq new
+                 (delete-duplicates
+                  (nconc
+                   (if (listp v) v (list v))
+                   (if (listp orig) orig (list orig)))))
+           (ad-Orig-put-text-property start extent
+                                      'personality new object))
+         (when (< extent end)
+           (emacspeak-personality-prepend extent end v object))))))))
 
 (defun emacspeak-personality-remove  (start end
-					    personality
-					    &optional object)
+                                            personality
+                                            &optional object)
   "Remove specified personality from text bounded by start and end.
 Other existing personality properties on the text range are
 preserved."
   (when (and (integer-or-marker-p start)
-             (integer-or-marker-p end ))
+             (integer-or-marker-p end )
+             (not (= start end)))
     (ems-modify-buffer-safely
      (let ((orig (get-text-property start 'personality object))
-	   (new nil)
-	   (extent
-	    (next-single-property-change
-	     start 'personality (current-buffer) end)))
+           (new nil)
+           (extent
+            (next-single-property-change
+             start 'personality (current-buffer) end)))
        (cond
-	((null orig)			;simple case
-	 (when (< extent end)
-	   (emacspeak-personality-remove extent end personality)))
-	(t				;remove the new personality
-	 (setq new
-	       (cond
-		((equal orig personality) nil)
-		((listp orig)
-		 (remove personality orig))
-		(t nil)))
-	 (if new 
-	     (put-text-property start extent
-				'personality new object)
-	   (remove-text-properties start extent
-				   (list 'personality )
-				   object))
-	 (when (< extent end)
-	   (emacspeak-personality-remove extent end
-					 personality))))))))
+        ((null orig)                    ;simple case
+         (when (< extent end)
+           (emacspeak-personality-remove extent end personality)))
+        (t                              ;remove the new personality
+         (setq new
+               (cond
+                ((equal orig personality) nil)
+                ((listp orig)
+                 (remove personality orig))
+                (t nil)))
+         (if new
+             (ad-Orig-put-text-property start extent
+                                        'personality new object)
+           (ad-Orig-remove-text-properties start extent
+                                           (list 'personality )
+                                           object))
+         (when (< extent end)
+           (emacspeak-personality-remove extent end
+                                         personality))))))))
 
 ;;}}}
 ;;{{{ helper: face-p
@@ -222,7 +225,7 @@ preserved."
       (memq 'font-lock-face plist)))
 (defsubst ems-plain-cons-p (value)
   "Help identify (a . b)."
-  (and (consp value)	
+  (and (consp value)
        (equal value (last value))
        (cdr value)))
 
@@ -255,114 +258,117 @@ displayed in the messages area."
 (defvar emacspeak-personality-unmapped-faces (make-hash-table)
   "Records faces that we have not yet mapped to personalities.")
 
-(defadvice put-text-property (after emacspeak-personality  pre act) 
+(defadvice put-text-property (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
-  (let ((start (ad-get-arg 0))
-        (end (ad-get-arg 1 ))
-        (prop (ad-get-arg 2))
-        (value (ad-get-arg 3 ))
-        (object (ad-get-arg 4))
-        (voice nil))
-    (when (and  emacspeak-personality-voiceify-faces
-                (or (eq prop 'face) (eq prop 'font-lock-face)))
-      (condition-case nil
-          (progn
-            (cond
-             ((symbolp value)
-              (setq voice (voice-setup-get-voice-for-face value)))
-             ((ems-plain-cons-p value))	;;pass on plain cons
-             ( (listp value)
-               (setq voice
-                     (delete nil 
-                             (mapcar   #'voice-setup-get-voice-for-face value))))
-             (t (message "Got %s" value)))
-            (when voice
-              (funcall emacspeak-personality-voiceify-faces start end voice object))
-            (when (and emacspeak-personality-show-unmapped-faces
-                       (not voice))
+  (when voice-lock-mode
+    (let ((start (ad-get-arg 0))
+          (end (ad-get-arg 1 ))
+          (prop (ad-get-arg 2))
+          (value (ad-get-arg 3 ))
+          (object (ad-get-arg 4))
+          (voice nil))
+      (when (and  emacspeak-personality-voiceify-faces
+                  (not (= start end))
+                  (or (eq prop 'face) (eq prop 'font-lock-face)))
+        (condition-case nil
+            (progn
               (cond
-               ((listp value)
-                (mapcar #'(lambda (v)
-                            (puthash  v t emacspeak-personality-unmapped-faces))
-                        value))
-               (t (puthash  value t emacspeak-personality-unmapped-faces)))))
-        (error nil)))))
+               ((symbolp value)
+                (setq voice (voice-setup-get-voice-for-face value)))
+               ((ems-plain-cons-p value)) ;;pass on plain cons
+               ( (listp value)
+                 (setq voice
+                       (delq nil
+                             (mapcar   #'voice-setup-get-voice-for-face value))))
+               (t (message "Got %s" value)))
+              (when voice
+                (funcall emacspeak-personality-voiceify-faces start end voice object))
+              (when (and emacspeak-personality-show-unmapped-faces
+                         (not voice))
+                (cond
+                 ((listp value)
+                  (mapcar #'(lambda (v)
+                              (puthash  v t emacspeak-personality-unmapped-faces))
+                          value))
+                 (t (puthash  value t emacspeak-personality-unmapped-faces)))))
+          (error nil))))))
 
-(defadvice add-text-properties (after emacspeak-personality  pre act) 
+(defadvice add-text-properties (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
-  (let ((start (ad-get-arg 0))
-        (end (ad-get-arg 1 ))
-        (properties (ad-get-arg 2))
-        (object (ad-get-arg 3))
-        (facep nil)
-        (voice nil)
-        (value nil))
-    (setq facep (emacspeak-personality-plist-face-p properties))
-    (when (and  emacspeak-personality-voiceify-faces
-		facep)
-      (setq value (second facep))
-      (condition-case nil
-          (progn
-            (cond
-             ((symbolp value)
-              (setq voice (voice-setup-get-voice-for-face   value)))
-	     ((ems-plain-cons-p value))	;;pass on plain cons
-             ( (listp value)
-               (setq voice
-                     (delete nil 
-                             (mapcar   #'voice-setup-get-voice-for-face value))))
-             (t (message "Got %s" value)))
-            (when voice
-              (funcall emacspeak-personality-voiceify-faces start end voice object))
-            (when (and emacspeak-personality-show-unmapped-faces
-                       (not voice))
+  (when voice-lock-mode
+    (let ((start (ad-get-arg 0))
+          (end (ad-get-arg 1 ))
+          (properties (ad-get-arg 2))
+          (object (ad-get-arg 3))
+          (facep nil)
+          (voice nil)
+          (value nil))
+      (setq facep (emacspeak-personality-plist-face-p properties))
+      (when (and  emacspeak-personality-voiceify-faces
+                  facep)
+        (setq value (second facep))
+        (condition-case nil
+            (progn
               (cond
-               ((listp value)
-                (mapcar #'(lambda (v)
-                            (puthash  v t emacspeak-personality-unmapped-faces))
-                        value))
-               (t (puthash  value t emacspeak-personality-unmapped-faces)))))
-        (error nil)))))
+               ((symbolp value)
+                (setq voice (voice-setup-get-voice-for-face   value)))
+               ((ems-plain-cons-p value)) ;;pass on plain cons
+               ( (listp value)
+                 (setq voice
+                       (delq nil
+                             (mapcar   #'voice-setup-get-voice-for-face value))))
+               (t (message "Got %s" value)))
+              (when voice
+                (funcall emacspeak-personality-voiceify-faces start end voice object))
+              (when (and emacspeak-personality-show-unmapped-faces
+                         (not voice))
+                (cond
+                 ((listp value)
+                  (mapcar #'(lambda (v)
+                              (puthash  v t emacspeak-personality-unmapped-faces))
+                          value))
+                 (t (puthash  value t emacspeak-personality-unmapped-faces)))))
+          (error nil))))))
 
-(defadvice set-text-properties (after emacspeak-personality  pre act) 
+(defadvice set-text-properties (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
-  (let ((start (ad-get-arg 0))
-        (end (ad-get-arg 1 ))
-        (properties (ad-get-arg 2))
-        (object (ad-get-arg 3))
-        (facep nil)
-        (voice nil)
-        (value nil))
-    (setq facep (emacspeak-personality-plist-face-p properties))
-    (when (and  emacspeak-personality-voiceify-faces
-		facep)
-      (setq value (second facep))
-      (condition-case nil
-          (progn
-            (cond
-             ((symbolp value)
-              (setq voice (voice-setup-get-voice-for-face   value)))
-             ((ems-plain-cons-p value))	;;pass on plain cons
-             ( (listp value)
-               (setq voice
-                     (delete nil 
-                             (mapcar   #'voice-setup-get-voice-for-face value))))
-             (t (message "Got %s" value)))
-            (when voice
-              (funcall emacspeak-personality-voiceify-faces start end voice object))
-            (when (and emacspeak-personality-show-unmapped-faces
-                       (not voice))
+  (when voice-lock-mode
+    (let ((start (ad-get-arg 0))
+          (end (ad-get-arg 1 ))
+          (properties (ad-get-arg 2))
+          (object (ad-get-arg 3))
+          (facep nil)
+          (voice nil)
+          (value nil))
+      (setq facep (emacspeak-personality-plist-face-p properties))
+      (when (and  emacspeak-personality-voiceify-faces
+                  facep)
+        (setq value (second facep))
+        (condition-case nil
+            (progn
               (cond
-               ((listp value)
-                (mapcar #'(lambda (v)
-                            (puthash  v t emacspeak-personality-unmapped-faces))
-                        value))
-               (t (puthash  value t emacspeak-personality-unmapped-faces))))
-            )
-        (error nil))
-      )))
+               ((symbolp value)
+                (setq voice (voice-setup-get-voice-for-face   value)))
+               ((ems-plain-cons-p value)) ;;pass on plain cons
+               ( (listp value)
+                 (setq voice
+                       (delq nil
+                             (mapcar   #'voice-setup-get-voice-for-face value))))
+               (t (message "Got %s" value)))
+              (when voice
+                (funcall emacspeak-personality-voiceify-faces start end voice object))
+              (when (and emacspeak-personality-show-unmapped-faces
+                         (not voice))
+                (cond
+                 ((listp value)
+                  (mapcar #'(lambda (v)
+                              (puthash  v t emacspeak-personality-unmapped-faces))
+                          value))
+                 (t (puthash  value t emacspeak-personality-unmapped-faces))))
+              )
+          (error nil))))))
 
-(defadvice propertize (around emacspeak-personality  pre act) 
+(defadvice propertize (around emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
   (let ((string (ad-get-arg 0))
         (properties (ad-get-args 1))
@@ -372,7 +378,7 @@ displayed in the messages area."
     (setq facep (emacspeak-personality-plist-face-p properties))
     (cond
      ((and  emacspeak-personality-voiceify-faces
-	    facep)
+            facep)
       ad-do-it
       (setq value (second facep))
       (condition-case nil
@@ -380,18 +386,14 @@ displayed in the messages area."
             (cond
              ((symbolp value)
               (setq voice (voice-setup-get-voice-for-face   value)))
-             ;; ((and (consp value)	;check for plain cons and pass
-	     ;;                    (equal value (last value)))
-	     ;; 	      nil)
              ( (listp value)
                (setq voice
-                     (delete nil 
-                             (mapcar   #'voice-setup-get-voice-for-face value))))
+                     (delq nil
+                           (mapcar   #'voice-setup-get-voice-for-face value))))
              (t (message "Got %s" value)))
             (when voice
               (funcall emacspeak-personality-voiceify-faces 0
-		       (length ad-return-value) voice ad-return-value)
-              )
+                       (length ad-return-value) voice ad-return-value))
             (when (and emacspeak-personality-show-unmapped-faces
                        (not voice))
               (cond
@@ -406,18 +408,34 @@ displayed in the messages area."
 
 (defadvice remove-text-properties (before emacspeak-personality pre act comp)
   "Undo any voiceification if needed."
-  (let  ((start (ad-get-arg 0))
-         (end (ad-get-arg 1))
-         (props (ad-get-arg 2))
-         (object (ad-get-arg 3))
-         (voice nil)
-         (face nil))
-    (when (emacspeak-personality-plist-face-p props) ;;; simple minded for now
-      (put-text-property start end
-			 'personality nil object))))
+  (when voice-lock-mode
+    (let  ((start (ad-get-arg 0))
+           (end (ad-get-arg 1))
+           (props (ad-get-arg 2))
+           (object (ad-get-arg 3))
+           (voice nil)
+           (face nil))
+      (when (and (not (= start end))
+                 (emacspeak-personality-plist-face-p props) ) ;;; simple minded for now
+        (ad-Orig-put-text-property start end
+                                   'personality nil object)))))
+
+(defadvice remove-list-of-text-properties (before emacspeak-personality pre act comp)
+  "Undo any voiceification if needed."
+  (when voice-lock-mode
+    (let  ((start (ad-get-arg 0))
+           (end (ad-get-arg 1))
+           (props (ad-get-arg 2))
+           (object (ad-get-arg 3))
+           (voice nil)
+           (face nil))
+      (when (and (not (= start end))
+                 (emacspeak-personality-plist-face-p props) ) ;;; simple minded for now
+        (put-text-property start end
+                           'personality nil object)))))
 
 ;;}}}
-;;{{{ advice overlay-put 
+;;{{{ advice overlay-put
 
 (defcustom emacspeak-personality-voiceify-overlays
   'emacspeak-personality-prepend
@@ -434,7 +452,7 @@ Append means place corresponding personality at the end."
                  (const :tag "Append" emacspeak-personality-append))
   :group 'emacspeak-personality)
 
-(defadvice overlay-put (after emacspeak-personality  pre act) 
+(defadvice overlay-put (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
   (let ((overlay (ad-get-arg 0))
         (prop (ad-get-arg 1))
@@ -453,28 +471,28 @@ Append means place corresponding personality at the end."
         (setq voice (voice-setup-get-voice-for-face   value)))
        ((listp value)
         (setq voice
-              (delete nil
-                      (mapcar
-                       #'voice-setup-get-voice-for-face value))))
+              (delq nil
+                    (mapcar
+                     #'voice-setup-get-voice-for-face value))))
        (t (message "Got %s" value)))
       (when voice
         (and emacspeak-personality-voiceify-overlays
              (funcall emacspeak-personality-voiceify-overlays
-		      (overlay-start overlay)
-		      (overlay-end overlay)
-		      voice))
+                      (overlay-start overlay)
+                      (overlay-end overlay)
+                      voice))
         (overlay-put overlay 'personality voice))
       (when (and emacspeak-personality-show-unmapped-faces
                  (not voice))
         (cond
          ((listp value)
-	  (mapcar #'(lambda (v)
-		      (puthash  v t emacspeak-personality-unmapped-faces))
-		  value))
+          (mapcar #'(lambda (v)
+                      (puthash  v t emacspeak-personality-unmapped-faces))
+                  value))
          (t (puthash  value t
                       emacspeak-personality-unmapped-faces)))))))
 
-(defadvice move-overlay (before emacspeak-personality  pre act) 
+(defadvice move-overlay (before emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
   (let ((overlay (ad-get-arg 0))
         (beg (ad-get-arg 1))
@@ -493,6 +511,18 @@ Append means place corresponding personality at the end."
       (funcall emacspeak-personality-voiceify-overlays
                beg end voice))))
 
+;;}}}
+;;{{{ silence font-lock's error messages
+
+(loop for f in
+      '(font-lock-default-fontify-region
+        font-lock-default-fontify-buffer)
+      do
+      (eval
+       `(defadvice ,f (around emacspeak pre act comp)
+          "Silence auditory feedback from redisplay errors."
+          (ems-with-errors-silenced ad-do-it))))
+
 ;;}}}
 (provide 'emacspeak-personality )
 ;;{{{ end of file
