@@ -1,6 +1,6 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris
-;;; $Id: emacspeak-tetris.el,v 20.0 2004/05/01 01:16:23 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-tetris.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to tetris
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2004/05/01 01:16:23 $ |
-;;;  $Revision: 20.0 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2003, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -41,7 +41,9 @@
 ;;{{{  Required modules
 
 (require 'emacspeak-preamble)
-(require 'tetris)
+(condition-case nil
+    (require 'tetris)            ;FC2 Emacs doesn't contain tetris.el?
+  )
 ;;}}}
 ;;{{{  Introduction 
 
@@ -62,8 +64,8 @@
     (setq emacspeak-tetris-pronunciations-defined t)
     (mapcar
      #'(lambda (entry)
-	 (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
-						   (car entry) (cdr entry)))
+         (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
+                                                   (car entry) (cdr entry)))
      '(("" . " 1 ")
        ("" . " 6 ")
        ("" . " 7 ")
@@ -72,7 +74,7 @@
        ("" . " 3 ")
        ("" . " 2 ")
        (" " . "-")
-       ("" . "")			;border char
+       ("" . "")                      ;border char
        ("." . ""))))
   (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
             (not emacspeak-pronounce-pronunciation-table))
@@ -90,7 +92,7 @@
 (aset emacspeak-tetris-shape-name-table 4 " z ")
 (aset emacspeak-tetris-shape-name-table 5 " s ")
 (aset emacspeak-tetris-shape-name-table 6 " inverted t ")
-(aset emacspeak-tetris-shape-name-table 7 " edge ")
+(aset emacspeak-tetris-shape-name-table 7 " line ")
 (defsubst emacspeak-tetris-blank-row ()
   (declare (special tetris-width))
   (make-string tetris-width  0))
@@ -151,8 +153,8 @@
   (dtk-speak
    (format "%s %s at rotation  %s next is %s"
            (if emacspeak-tetris-filled-a-row 
-	       tetris-n-rows
-	     " ")
+               tetris-n-rows
+             " ")
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-rot
            (emacspeak-tetris-shape-name (1+ tetris-next-shape))))
@@ -174,7 +176,7 @@
                      tetris-shape tetris-rot))
   (message "%s at %s %s  at rotation %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
-	   tetris-pos-x
+           tetris-pos-x
            tetris-pos-y
            tetris-rot))
 
@@ -328,6 +330,7 @@ concentration and the game is a good mental challenge. "
     (setq tetris-width emacspeak-tetris-width)
     (setq emacspeak-tetris-blank-row (emacspeak-tetris-blank-row))
     ad-do-it
+    (dtk-set-punctuations 'all)
     (emacspeak-tetris-define-pronunciations)
     (emacspeak-tetris-define-keys)
     (emacspeak-tetris-speak-current-shape)
@@ -418,10 +421,10 @@ concentration and the game is a good mental challenge. "
   (define-key tetris-mode-map "N" 'tetris-start-game)
   (define-key  tetris-mode-map "c" 'emacspeak-tetris-speak-row)
   (loop for i from 0 to 9
-	do
-	(define-key tetris-mode-map
-	  (format "%s" i)
-	  'tetris-move-to-x-pos))
+        do
+        (define-key tetris-mode-map
+          (format "%s" i)
+          'tetris-move-to-x-pos))
   (define-key tetris-mode-map "a" 'tetris-move-left-edge)
   (define-key tetris-mode-map "e" 'tetris-move-right-edge)
   (define-key tetris-mode-map "l" 'tetris-move-right)
@@ -530,7 +533,7 @@ a(defun tetris-move-right-edge ()
     (setq result
           (loop for y from tetris-top-left-y
                 to (+ tetris-height tetris-top-left-y)
-		collect (gamegrid-get-cell x y)))
+                collect (gamegrid-get-cell x y)))
     (mapconcat 'char-to-string result "")))
 
 (defun emacspeak-tetris-speak-column (&optional x)
