@@ -1,6 +1,6 @@
 ;;; outloud-voices.el --- Define various device independent voices in terms of OutLoud tags
-;;; $Id: outloud-voices.el,v 20.0 2004/05/01 01:16:24 raman Exp $
-;;; $Author: raman $
+;;; $Id: outloud-voices.el 5251 2007-09-03 19:52:21Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Module to set up Eloquent voices and personalities
 ;;; Keywords: Voice, Personality, IBM ViaVoice Outloud
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2004/05/01 01:16:24 $ |
-;;;  $Revision: 20.0 $ |
+;;; $Date: 2007-09-03 12:52:21 -0700 (Mon, 03 Sep 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2003, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -56,9 +56,6 @@
 ;;}}}
 ;;{{{  voice table
 
-(defvar tts-default-voice 'paul 
-  "Default voice used. ")
-
 (defvar outloud-default-voice-string "`v1"
   "Default Outloud tag for  default voice --set to be a no-op.")
 
@@ -174,16 +171,16 @@ and TABLE gives the values along that dimension."
                     (second setting)
                     (third setting)))))
    '(
-     (0 0 90)
-     (1 13 81 )
-     (2 26 72)
-     (3 39 63)
-     (4 52 54  )
+     (0 44 52)
+     (1 50 58 )
+     (2 56 56)
+     (3 58 54)
+     (4 62 52  )
      (5 65 50)
-     (6 74 40)
-     (7 83 30 )
-     (8 87 26)
-     (9 92 21)))
+     (6 69 48)
+     (7 73 46 )
+     (8 77 44)
+     (9 82 40)))
   (outloud-css-set-code-table 'paul 'average-pitch table ))
 
 ;;}}}
@@ -222,10 +219,10 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-	    (first setting)
-	    (format " `vb%s `vh% s"
-		    (second setting)
-		    (third setting)))))
+            (first setting)
+            (format " `vb%s `vh% s"
+                    (second setting)
+                    (third setting)))))
    '(
      (0 5 70)
      (1 17 66)
@@ -246,7 +243,7 @@ and TABLE gives the values along that dimension."
   (or family (setq family 'paul))
   (if value 
       (aref (outloud-css-get-code-table family 'average-pitch)
-	    value)
+            value)
     ""))
 
 ;;}}}
@@ -264,9 +261,9 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-	    (first setting)
-	    (format " `vf%s  "
-		    (second setting)))))
+            (first setting)
+            (format " `vf%s  "
+                    (second setting)))))
    '(
      (0 0 )
      (1 5 )
@@ -288,9 +285,9 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-	    (first setting)
-	    (format " `vf%s  "
-		    (second setting)))))
+            (first setting)
+            (format " `vf%s  "
+                    (second setting)))))
    '(
      (0 0 )
      (1 5 )
@@ -334,7 +331,7 @@ and TABLE gives the values along that dimension."
   (or family (setq family 'paul))
   (if value 
       (aref (outloud-css-get-code-table family 'pitch-range)
-	    value)
+            value)
     ""))
 
 ;;}}}
@@ -348,8 +345,8 @@ and TABLE gives the values along that dimension."
   (mapcar
    #'(lambda (setting)
        (aset table (first setting)
-	     (format " `vr%s  "
-		     (second setting))))
+             (format " `vr%s  "
+                     (second setting))))
 ;;; stress markers not used for now.
    '(
      (0 0 "`00")
@@ -371,7 +368,7 @@ and TABLE gives the values along that dimension."
   (or family (setq family 'paul ))
   (if value 
       (aref (outloud-css-get-code-table family 'stress)
-	    value)
+            value)
     ""))
 
 ;;}}}
@@ -409,7 +406,7 @@ and TABLE gives the values along that dimension."
   (or family (setq family 'paul))
   (if value 
       (aref (outloud-css-get-code-table family 'richness)
-	    value)
+            value)
     ""))
 
 ;;}}}
@@ -426,14 +423,14 @@ and TABLE gives the values along that dimension."
 (defun outloud-define-voice-from-speech-style (name style)
   "Define NAME to be a outloud voice as specified by settings in STYLE."
   (let* ((family(acss-family style))
-	 (command
-	  (concat 
-	   (outloud-get-family-code family)
+         (command
+          (concat 
+           (outloud-get-family-code family)
            (outloud-get-punctuations-code (acss-punctuations style))
-	   (outloud-get-average-pitch-code (acss-average-pitch style) family)
-	   (outloud-get-pitch-range-code (acss-pitch-range style) family)
-	   (outloud-get-stress-code (acss-stress style ) family)
-	   (outloud-get-richness-code (acss-richness style) family))))
+           (outloud-get-average-pitch-code (acss-average-pitch style) family)
+           (outloud-get-pitch-range-code (acss-pitch-range style) family)
+           (outloud-get-stress-code (acss-stress style ) family)
+           (outloud-get-richness-code (acss-richness style) family))))
     (outloud-define-voice name command)))
 
 ;;}}}
@@ -443,7 +440,7 @@ and TABLE gives the values along that dimension."
   "List defined voices."
   (declare (special outloud-voice-table))
   (loop for k being the hash-keys of outloud-voice-table 
-	collect   k))
+        collect   k))
 
 ;;}}}
 ;;{{{ Configurater 
@@ -451,22 +448,14 @@ and TABLE gives the values along that dimension."
 (defun outloud-configure-tts ()
   "Configure TTS environment to use ViaVoice  family of synthesizers."
   (declare (special tts-default-speech-rate
-                    outloud-default-speech-rate
-                    emacspeak-use-auditory-icons
-                    emacspeak-aumix-midi-available-p
-                    emacspeak-aumix-multichannel-capable-p))
+                    outloud-default-speech-rate))
   (fset 'tts-list-voices'outloud-list-voices)
   (fset 'tts-voice-defined-p 'outloud-voice-defined-p)
   (fset 'tts-get-voice-command 'outloud-get-voice-command)
-  (fset 'tts-voice-defined-p 'outloud-voice-defined-p)
   (fset 'tts-define-voice-from-speech-style 'outloud-define-voice-from-speech-style)
   (setq tts-default-speech-rate outloud-default-speech-rate)
-  (set-default 'tts-default-speech-rate outloud-default-speech-rate)
-  (when (and emacspeak-use-auditory-icons
-             (not emacspeak-aumix-multichannel-capable-p)
-             (not (emacspeak-using-midi-p))
-             emacspeak-aumix-midi-available-p)
-    (emacspeak-set-auditory-icon-player 'emacspeak-play-midi-icon)))
+  (set-default 'tts-default-speech-rate
+               outloud-default-speech-rate))
 
 ;;}}}
 (provide 'outloud-voices)
